#
# spec file for package steam
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           steam
Version:        1.0.0.54
Release:        4.2
Summary:        Installer for Valve's digital software distribution service
# "Limited Installation License"
License:        SUSE-Freeware
Group:          Amusements/Games/Other
Url:            http://www.steampowered.com/
Source:         http://repo.steampowered.com/steam/pool/steam/s/steam/steam_%{version}.tar.gz
Source1:        steamruntime-fix
Source2:        steam.appdata.xml
# https://github.com/ValveSoftware/steam-for-linux/issues/3273
Patch0:         invoke-libstdc-removal-before-starting-steam.patch
# PATCH-FEATURE-OPENSUSE allow-non-root-controller-access.patch -- Allow non root users to access the steam-controller
Patch1:         allow-non-root-controller-access.patch
BuildRequires:  hicolor-icon-theme
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  pkgconfig(udev)

# dep_postfix macro is used to append "-32bit" to dependencies for x86_64 on openSUSE
%define dep_postfix %{nil}
%ifarch x86_64
  %define dep_postfix -32bit
%endif

Requires:       Mesa-libGL1%{dep_postfix}
Requires:       alsa%{dep_postfix} >= 1.0.23
Requires:       alsa-devel%{dep_postfix} >= 1.0.23
Requires:       dbus-1-glib%{dep_postfix}
Requires:       gtk2-engine-oxygen%{dep_postfix}
Requires:       libSDL-1_2-0%{dep_postfix} >= 1.2.10
Requires:       libX11-6%{dep_postfix} >= 1.4.99.1
Requires:       libXdmcp6%{dep_postfix}
Requires:       libXext6%{dep_postfix}
Requires:       libXfixes3%{dep_postfix}
Requires:       libXi6%{dep_postfix} >= 1.2.99.4
Requires:       libXrandr2%{dep_postfix} >= 1.2.99.3
Requires:       libXrender1%{dep_postfix}
Requires:       libatk-1_0-0%{dep_postfix}
Requires:       libcairo2%{dep_postfix} >= 1.6.0
Requires:       libcurl4%{dep_postfix} >= 7.16.2-1
Requires:       libdbus-1-3%{dep_postfix} >= 1.2.14
Requires:       libfreetype6%{dep_postfix} >= 2.3.9
%if 0%{?suse_version} >= 1315
Requires:       libgcrypt20%{dep_postfix} >= 1.6.1
%else
Requires:       libgcrypt11%{dep_postfix} >= 1.4.5
%endif
Requires:       libgdk_pixbuf-2_0-0%{dep_postfix} >= 2.22.0
Requires:       libglib-2_0-0%{dep_postfix} >= 2.14.0
Requires:       libgmodule-2_0-0%{dep_postfix}
Requires:       libgobject-2_0-0%{dep_postfix}
Requires:       libgtk-2_0-0%{dep_postfix} >= 2.24.0
Requires:       libnm-glib4%{dep_postfix}
Requires:       libnm-util2%{dep_postfix}
Requires:       libogg0%{dep_postfix} >= 1.0
Requires:       libpango-1_0-0%{dep_postfix} >= 1.22.0
Requires:       libpixman-1-0%{dep_postfix} >= 0.24.4
Requires:       libpng12-0%{dep_postfix} >= 1.2.13
Requires:       libpulse0%{dep_postfix} >= 0.99.1
Requires:       libtheora0%{dep_postfix} >= 1.0
Requires:       libvorbis0%{dep_postfix} >= 1.1.2
Requires:       mozilla-nspr%{dep_postfix} >= 1.8.0.10
Requires:       mozilla-nss%{dep_postfix} >= 3.12.3
Requires:       cups-libs%{dep_postfix} >= 1.4.0
Requires:       fontconfig%{dep_postfix} >= 2.8.0
Requires:       glibc%{dep_postfix} >= 2.15
Requires:       openal-soft >= 1.13
Requires:       zlib%{dep_postfix} >= 1.2.3.3
Requires:       libgcc_s1%{dep_postfix} >= 4.1.1
Requires:       libopenal1%{dep_postfix} >= 1.13
Requires:       libstdc++6%{dep_postfix} >= 4.6

# our own builds of libcrypto.so.1 and libssl.so.1.
Requires:	libopenssl1_0_0-steam
%ifarch x86_64
Requires:	libopenssl1_0_0-steam-32bit
%endif

# from steamdeps.txt which uses Debian package syntax
Requires:       curl
Requires:       xz
Requires:       zenity
Requires:       libxcb-dri2-0%{dep_postfix}
Requires:       libxcb-glx0%{dep_postfix}

%description
Steam is a software distribution service with an online store, automated
installation, automatic updates, achievements, SteamCloud synchronized
savegame and screenshot functionality, and many social features.

This package will fetch and install the Steam bootstrap. Start Steam to
complete the installation of the client for the current user.

%package        controller
Summary:        Steam Controller
Group:          Hardware/Joystick
Requires:       steam = %{version}

%description controller
The Steam Controller features dual trackpads, HD haptic feedback, dual-stage
triggers, back grip buttons, and fully-customizable control schemes.
Make sure that all users, which should have access to the steam-controller,
are in the "games" group.

%package        vr
Summary:        Steam VR
Group:          Hardware/Joystick
Requires:       steam = %{version}

%description vr
A full-featured, 360° room-scale virtual reality experience.

%prep
%setup -q -n steam
%patch0 -p1
%patch1 -p1

%build

%install
make DESTDIR=%{buildroot} install-bin install-docs install-icons install-bootstrap install-desktop

# TODO: Patch it so it works with zypper or at least does not invoke apt-get.
rm %{buildroot}%{_bindir}/steamdeps

mkdir -p %{buildroot}%{_udevrulesdir}
cp lib/udev/rules.d/* %{buildroot}%{_udevrulesdir}

cp %{SOURCE1} %{buildroot}%{_bindir}
chmod +x %{buildroot}%{_bindir}/steamruntime-fix

%suse_update_desktop_file -n -r steam Game Amusement

dos2unix %{buildroot}%{_datadir}/doc/steam/steam_install_agreement.txt

# https://en.opensuse.org/openSUSE:AppStore
install -Dm0644 %{SOURCE2} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%fdupes %{buildroot}%{_prefix}

%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun

%post controller
%{?udev_rules_update:%udev_rules_update}

%postun controller
%{?udev_rules_update:%udev_rules_update}

%post vr
%{?udev_rules_update:%udev_rules_update}

%postun vr
%{?udev_rules_update:%udev_rules_update}

%files
%defattr(-,root,root)
%{_bindir}/steam
%{_bindir}/steamruntime-fix
%dir %{_prefix}/lib/steam
%{_prefix}/lib/steam/bootstraplinux_ubuntu12_32.tar.xz
%{_datadir}/pixmaps/steam_tray_mono.png
%{_datadir}/pixmaps/steam.png
%{_datadir}/applications/steam.desktop
%{_datadir}/icons/hicolor/*/apps/steam.png
%dir %{_datadir}/doc/steam
%doc %{_datadir}/doc/steam/steam_install_agreement.txt
%doc %{_datadir}/doc/steam/README
%doc debian/changelog
%{_mandir}/man6/steam.6.gz
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%files controller
%{_udevrulesdir}/99-steam-controller-perms.rules

%files vr
%{_udevrulesdir}/60-HTC-Vive-perms.rules

%changelog
* Thu Jan 26 2017 rpm@fthiessen.de
- Updated to current version to fix steam controller in wireless
  mode. boo#1022010
* Tue Dec 13 2016 develop7@develop7.info
- update to version 1.0.0.54
- refreshed allow-non-root-controller-access.patch
* Sat Nov 19 2016 mailaender@opensuse.org
- update to version 1.0.0.53
  * Update udev rules for HTC Vive and order them so they run after
  50-udev-default.rules but before 73-seat-late.rules
- Add appdata.xml for https://software.opensuse.org/appstore
* Sat Oct  1 2016 jimmy@boombatower.com
- Surround all home directory usages with quotes.
* Wed Sep 28 2016 jimmy@boombatower.com
- Search and remove libstdc from steam library directories as well
  to ensure apps shipping their own incompatible versions work.
* Mon Sep 26 2016 jimmy@boombatower.com
- correct replacement of 64bit openssl libraries in steamruntime.
* Mon Sep 12 2016 meissner@suse.com
- require our own builds of the openssl libraries
  and replace them on runtime. bsc#988273
* Mon Aug 15 2016 rpm@fthiessen.de
- Added allow-non-root-controller-access.patch for fixing
  boo#986901
- Droped special handling of openSUSE <= 12.3 as it is not
  maintained anymore.
* Sun Jul 10 2016 jimmy@boombatower.com
- Add invoke-libstdc-removal-before-starting-steam.patch to resolve
  long standing issue:
  https://github.com/ValveSoftware/steam-for-linux/issues/3273
* Mon Jun 13 2016 mailaender@opensuse.org
- update to version 1.0.0.52
- add SteamVR (HTC Vive) support
- add (Debian) changelog
* Fri Apr 29 2016 mailaender@opensuse.org
- don't strip the translation from .desktop file (fixes boo#974334)
* Sat Mar  5 2016 mailaender@opensuse.org
- add Steam controller support
* Sat Nov 21 2015 mailaender@opensuse.org
- update to version 1.0.0.51
* Thu Sep 10 2015 ecsos@opensuse.org
- fix build error for openSUSE 13.1 and 13.2
* Wed Sep  9 2015 dimstar@opensuse.org
- on openSUSE Leap 42.1, we have libgcrypt20-32bit.
* Mon Jun 22 2015 robert.munteanu@gmail.com
- Require alsa-devel to fix launching of unity3D games (
    https://github.com/ValveSoftware/steam-for-linux/issues/3888 )
* Wed May 13 2015 mailaender@opensuse.org
- update to version 1.0.0.50
  * Added libXinerama and libXext to the bootstrap runtime to fix AMD
    graphics driver crashing if these aren't present.
* Mon Dec 29 2014 mailaender@opensuse.org
- remove Fedora exceptions as they got their own RPM
- rework this from fetch script to a real package
- adhere to en.opensuse.org/SourceUrls
- adhere to en.opensuse.org/openSUSE:Packaging_desktop_menu_categories
- clean the package from duplicate icon files
* Sat Oct  4 2014 mailaender@opensuse.org
- update to 1.0.0.49
  * Update packaged icons.
  * Update liblibstdc++ file version to match new runtime.
* Tue Jul  8 2014 speilicke@suse.com
- Require libgcrypt20 on 13.20 or newer, libgcrypt11 was dropped there
* Fri Jun 20 2014 romulasry@gmail.com
- update to 1.0.0.48
* Wed May 28 2014 martadinata666@gmail.com
- update to 1.0.0.47
* Thu Dec 26 2013 mailaender@opensuse.org
- Don't spam the subscriber agreement in the RPM console as Steam
  itself will display a proper EULA in a GUI to accept on first
  start when it downloads the real runtime and client.
- Update instructions of the RPM file description.
- Added missing desktop, icon, mime database update macros.
* Thu Dec  5 2013 mailaender@opensuse.org
- update to 1.0.0.45
- explicit file attributes required in spec to fix build in 12.2
* Sun Dec  1 2013 mihai.petracovici@gmail.com
- Spec file clean-up
  * Package now properly uninstalls
* Sat Nov 23 2013 mailaender@opensuse.org
- update to 1.0.0.44
* Sat Oct 12 2013 mailaender@opensuse.org
- update to 1.0.0.43
* Mon Sep 16 2013 bwiedemann@suse.com
- require dbus-1-glib-32bit libnm-glib4-32bit libnm-util2-32bit
* Mon Sep  9 2013 mailaender@opensuse.org
- update to 1.0.0.41
* Sun Jul  7 2013 mailaender@opensuse.org
- update to 1.0.0.39
* Wed Mar 13 2013 mailaender@opensuse.org
- update to 1.0.0.36
- display EULA before installation
* Tue Mar 12 2013 mailaender@opensuse.org
- fix openal dependency for openSUSE 12.3 (bnc#808951)
* Wed Mar  6 2013 mailaender@opensuse.org
- update to 1.0.0.35
- fix problems with 32bit dependencies on x64 (bnc#806576)
* Sun Feb 24 2013 mailaender@opensuse.org
- update to 1.0.0.33
- require tar instead of ar since we don't unpack a .deb anymore
- use lynx to dump only the text of the EULA without HTML tags
* Sat Feb 23 2013 buschmann23@opensuse.org
- added make and binutils explicit to the Requirements
* Tue Feb 19 2013 buschmann23@opensuse.org
- added conditional to requirements of gcc libs because names
  changed in openSUSE 12.3
* Sun Feb 17 2013 i@marguerite.su
- add Requires: libXdmcp6-32bit.
* Sat Feb 16 2013 mailaender@opensuse.org
- update to 1.0.0.28
* Sun Feb 10 2013 mailaender@opensuse.org
- updated to 1.0.0.25
- use the new tar.gz provided by Valve
* Fri Feb  1 2013 mailaender@opensuse.org
- updated to 1.0.0.22
- created fetch-steam.sh to circumvent the "Limited Installation License"
- removed all non-free binaries and scripts distributed by Valve
* Fri Dec 21 2012 prusnak@opensuse.org
- updated to 1.0.0.18
* Thu Dec 20 2012 prusnak@opensuse.org
- spec cleanup
* Sat Dec  8 2012 jdmulloy@gmail.com
- Added support for x86_64 packages
- Fixed libpng dependency for openSUSE
- Added libopenal1-soft and Mesa-libGL1 dependencices for openSUSE
* Tue Nov 20 2012 mailaender@opensuse.org
- SUSE specific fixes
* Wed Nov  7 2012 spot@fedoraproject.org
- add more Requires (from downloaded bits, not packaged bits)
* Tue Nov  6 2012 spot@fedoraproject.org
- fedora specific libpng conditionalization
* Tue Nov  6 2012 spot@fedoraproject.org
- initial Fedora RPM packaging
